@@ -2,7 +2,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2013 Icinga Developer Team.
+// Copyright (c) 2009-present Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -80,6 +80,13 @@ Ext.ns('Cronk.grid');
     Cronk.grid.ColumnRenderer = {
 
         customColumnPerfdataSanitized: function (cfg) {
+
+            var multiLine = false;
+
+            if (!Ext.isEmpty(cfg.multiLine) && cfg.multiLine) {
+                multiLine = true;
+            }
+
             return function (value, metaData, record, rowIndex, colIndex, store) {
                 if (!value) {
                     return _('no value');
@@ -99,6 +106,10 @@ Ext.ns('Cronk.grid');
 
                 metaData.attr = 'ext:qtip="' + Ext.util.Format.htmlEncode(value) + '"';
 
+                if (multiLine === true) {
+                    value = String(value).nl2br();
+                }
+
                 return value;
             };
         },
