@@ -655,7 +655,7 @@ COPY cronk_principal_cronk (cpc_principal_id, cpc_cronk_id) FROM stdin;
 --
 
 COPY nsm_db_version (id, version, modified, created) FROM stdin;
-1	icinga-web/v1.10.0	2013-10-24 00:00:00	2013-10-24 00:00:00
+1	icinga-web/v1.11.1	2014-06-24 00:00:00	2014-06-24 00:00:00
 \.
 
 
@@ -993,6 +993,13 @@ CREATE UNIQUE INDEX user_name_unique ON nsm_user USING btree (user_name);
 CREATE INDEX user_search ON nsm_user USING btree (user_name, user_authsrc, user_authid, user_disabled);
 
 
+--
+-- Name: session_id_idx; Type: INDEX; Schema: public; Owner: icinga_web; Tablespace: 
+--
+
+CREATE UNIQUE INDEX session_id_idx ON nsm_session USING btree (session_id);
+
+
 --
 -- Name: ccnp; Type: FK CONSTRAINT; Schema: public; Owner: icinga_web
 --
